# Experiment with different colour/fill scales -------------------------------

vals <- seq(-4 * pi, 4 * pi, len = 50)
df <- expand.grid(x = vals, y = vals)
df$r <- with(df, sqrt(x ^ 2 + y ^ 2))
df$z <- with(df, cos(r ^ 2) * exp(- r / 6))
df$z_cut <- cut_interval(df$z, 9)

(p1 <- qplot(x, y, data = df, fill = z, geom = "tile")) 
(p2 <- qplot(x, y, data = df, fill = z_cut, geom = "tile"))

p1 + scale_fill_gradient(low = "white", 
  high = "black")

# Highlight deviations
p1 + scale_fill_gradient2()
p1 + scale_fill_gradient2(breaks = seq(-1, 1, 
  by = 0.25), limits = c(-1, 1))
p1 + scale_fill_gradient2(mid = "white", 
  low = "black", high = "black")

p2 + scale_fill_brewer(pal = "Blues")


# Changing ticks and labels --------------------------------------------------

qplot(carat, price, data = diamonds)
qplot(carat, price, data = diamonds) + 
  scale_x_log10() +
  scale_y_log10()

prices <- c(100, 500, 1000, 5000, 10000)
last_plot() + 
  scale_y_log10(breaks = prices)

last_plot() + 
  scale_y_log10(breaks = prices, labels = prices)
  
# Themes ---------------------------------------------------------------------

# Two built in themes.  The default:
qplot(carat, price, data = diamonds)

# And a theme with a white background:
qplot(carat, price, data = diamonds) + theme_bw()

# Use theme_set if you want it to apply to every
# future plot.
theme_set(theme_bw())

theme_bw()
theme_grey()


p <- qplot(displ, hwy, data = mpg) + 
  opts(title = "Bigger engines are less efficient")

# To modify a plot
p 
p + opts(plot.title = 
  theme_text(size = 12, face = "bold"))
p + opts(plot.title = theme_text(colour = "red"))
p + opts(plot.title = theme_text(angle = 45))
p + opts(plot.title = theme_text(hjust = 1))
